@@ -9,8 +9,6 @@ import logging
 import socket
 import sys
 
-from .listener import SimpleListenerManager, Event
-from .timer import NacosTimerManager, NacosTimer
 from .utils import get_md5
 
 try:
@@ -36,7 +34,7 @@ logging.basicConfig()
 logger = logging.getLogger()
 
 DEBUG = False
-VERSION = "0.0.3"
+VERSION = "0.1.1"
 
 DEFAULT_GROUP_NAME = "DEFAULT_GROUP"
 DEFAULT_NAMESPACE = ""
@@ -115,102 +113,6 @@ def parse_nacos_server_addr(server_addr):
     return sp[0], port
 
 
-class SubscribedLocalInstance(object):
-    def __init__(self, key, instance):
-        self.key = key
-        self.instance_id = instance["instanceId"]
-        self.md5 = get_md5(str(instance))
-        self.instance = instance
-
-
-class SubscribedLocalManager(object):
-    def __init__(self):
-        self.manager = {
-            # "key1": {
-            #     "LOCAL_INSTANCES": {
-            #         "instanceId1": None,
-            #         "instanceId2": None,
-            #         "instanceId3": None,
-            #         "instanceId4": None
-            #     },
-            #     "LISTENER_MANAGER": None
-            # },
-            # "key2": {
-            #     "LOCAL_INSTANCES": {
-            #         "instanceId1": "",
-            #         "instanceId2": "",
-            #         "instanceId3": "",
-            #         "instanceId4": ""
-            #     },
-            #     "LISTENER_MANAGER": None
-            # }
-        }
-
-    def do_listener_launch(self, key, event, slc):
-        listener_manager = self.get_local_listener_manager(key)
-        if listener_manager and isinstance(listener_manager, SimpleListenerManager):
-            listener_manager.do_launch(event, slc)
-
-    def get_local_listener_manager(self, key):
-        key_node = self.manager.get(key)
-        if not key_node:
-            return None
-        return key_node.get("LISTENER_MANAGER")
-
-    def add_local_listener(self, key, listener_fn):
-        if not self.manager.get(key):
-            self.manager[key] = {}
-        local_listener_manager = self.manager.get(key).get("LISTENER_MANAGER")
-
-        if not local_listener_manager or not isinstance(local_listener_manager, SimpleListenerManager):
-            self.manager.get(key)["LISTENER_MANAGER"] = SimpleListenerManager()
-        local_listener_manager = self.manager.get(key).get("LISTENER_MANAGER")
-        if not local_listener_manager:
-            return self
-        if isinstance(listener_fn, list):
-            listener_fn = tuple(listener_fn)
-            local_listener_manager.add_listeners(*listener_fn)
-        if isinstance(listener_fn, tuple):
-            local_listener_manager.add_listeners(*listener_fn)
-        #  just single listener function
-        else:
-            local_listener_manager.add_listener(listener_fn)
-        return self
-
-    def add_local_listener_manager(self, key, listener_manager):
-        key_node = self.manager.get(key)
-        if key_node is None:
-            key_node = {}
-        key_node["LISTENER_MANAGER"] = listener_manager
-        return self
-
-    def get_local_instances(self, key):
-        if not self.manager.get(key):
-            return None
-        return self.manager.get(key).get("LOCAL_INSTANCES")
-
-    def add_local_instance(self, slc):
-        if not self.manager.get(slc.key):
-            self.manager[slc.key] = {}
-        if not self.manager.get(slc.key).get('LOCAL_INSTANCES'):
-            self.manager.get(slc.key)['LOCAL_INSTANCES'] = {}
-        self.manager.get(slc.key)['LOCAL_INSTANCES'][slc.instance_id] = slc
-        return self
-
-    def remove_local_instance(self, slc):
-        key_node = self.manager.get(slc.key)
-        if not key_node:
-            return self
-        local_instances_node = key_node.get("LOCAL_INSTANCES")
-        if not local_instances_node:
-            return self
-        local_instance = local_instances_node.get(slc.instance_id)
-        if not local_instance:
-            return self
-        local_instances_node.pop(slc.instance_id)
-        return self
-
-
 class NacosClient:
     debug = False
 
@@ -259,9 +161,6 @@ class NacosClient:
         self.callback_tread_pool = None
         self.process_mgr = None
 
-        self.subscribed_local_manager = SubscribedLocalManager()
-        self.subscribe_timer_manager = NacosTimerManager()
-
         self.default_timeout = DEFAULTS["TIMEOUT"]
         self.auth_enabled = self.ak and self.sk
         self.cai_enabled = True
@@ -992,98 +891,6 @@ class NacosClient:
             logger.exception("[send-heartbeat] exception %s occur" % str(e))
             raise
 
-    def subscribe(self,
-                  listener_fn, listener_interval=7, *args, **kwargs):
-        """
-        reference at `/nacos/v1/ns/instance/list` in https://nacos.io/zh-cn/docs/open-api.html
-        :param listener_fn           监听方法，可以是元组，列表，单个监听方法
-        :param listener_interval     监听间隔，在 HTTP 请求 OpenAPI 时间间隔
-        :return:
-        """
-        service_name = kwargs.get("service_name")
-        if not service_name:
-            if len(args) > 0:
-                service_name = args[0]
-            else:
-                raise NacosException("`service_name` is required in subscribe")
-        self.subscribed_local_manager.add_local_listener(key=service_name, listener_fn=listener_fn)
-
-        #  判断是否是第一次订阅调用
-        class _InnerSubContext(object):
-            first_sub = True
-
-        def _compare_and_trigger_listener():
-            #  invoke `list_naming_instance`
-            latest_res = self.list_naming_instance(*args, **kwargs)
-            latest_instances = latest_res['hosts']
-            #  获取本地缓存实例
-            local_service_instances_dict = self.subscribed_local_manager.get_local_instances(service_name)
-            #  当前本地没有缓存，所有都是新的实例
-            if not local_service_instances_dict:
-                if not latest_instances or len(latest_instances) < 1:
-                    #  第一次订阅调用不通知
-                    if _InnerSubContext.first_sub:
-                        _InnerSubContext.first_sub = False
-                        return
-                for instance in latest_instances:
-                    slc = SubscribedLocalInstance(key=service_name, instance=instance)
-                    self.subscribed_local_manager.add_local_instance(slc)
-                    #  第一次订阅调用不通知
-                    if _InnerSubContext.first_sub:
-                        _InnerSubContext.first_sub = False
-                        return
-                    self.subscribed_local_manager.do_listener_launch(service_name, Event.ADDED, slc)
-            else:
-                local_service_instances_dict_copy = local_service_instances_dict.copy()
-                for instance in latest_instances:
-                    slc = SubscribedLocalInstance(key=service_name, instance=instance)
-                    local_slc = local_service_instances_dict.get(slc.instance_id)
-                    # 本地不存在实例缓存
-                    if local_slc is None:
-                        self.subscribed_local_manager.add_local_instance(slc)
-                        self.subscribed_local_manager.do_listener_launch(service_name, Event.ADDED, slc)
-                    # 本地存在实例缓存
-                    else:
-                        local_slc_md5 = local_slc.md5
-                        local_slc_id = local_slc.instance_id
-                        local_service_instances_dict_copy.pop(local_slc_id)
-                        # 比较md5,存在实例变更
-                        if local_slc_md5 != slc.md5:
-                            self.subscribed_local_manager.remove_local_instance(local_slc).add_local_instance(slc)
-                            self.subscribed_local_manager.do_listener_launch(service_name, Event.MODIFIED, slc)
-                #  still have instances in local marked deleted
-                if len(local_service_instances_dict_copy) > 0:
-                    for local_slc_id, slc in local_service_instances_dict_copy.items():
-                        self.subscribed_local_manager.remove_local_instance(slc)
-                        self.subscribed_local_manager.do_listener_launch(service_name, Event.DELETED, slc)
-
-        timer_name = 'service-subscribe-timer-{key}'.format(key=service_name)
-        subscribe_timer = NacosTimer(name=timer_name, interval=listener_interval, fn=_compare_and_trigger_listener)
-        subscribe_timer.scheduler()
-        self.subscribe_timer_manager.add_timer(subscribe_timer)
-
-    def unsubscribe(self, service_name, listener_name=None):
-        """
-        remove listener from subscribed  listener manager
-        :param service_name:    service_name
-        :param listener_name:   listener name
-        :return:
-        """
-        listener_manager = self.subscribed_local_manager.get_local_listener_manager(key=service_name)
-        if not listener_manager:
-            return
-        if listener_name:
-            listener_manager.remove_listener(listener_name)
-            return
-        listener_manager.empty_listeners()
-
-    def stop_subscribe(self):
-        """
-        stop subscribe timer scheduler
-        :return:
-        """
-        self.subscribe_timer_manager.stop()
-
 
 if DEBUG:
     NacosClient.set_debugging()
